@@ -4,6 +4,8 @@
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
 
+# pyre-strict
+
 # pyre-ignore-all-errors[16]: Undefined attribute of metric states.
 
 from typing import Iterable, Optional, Tuple, TypeVar, Union
@@ -207,12 +209,12 @@ class WindowedClickThroughRate(
                 self.click_total += metric.click_total.to(self.device)
                 self.weight_total += metric.weight_total.to(self.device)
             cur_size = min(metric.total_updates, metric.max_num_updates)
-            self.windowed_click_total[
-                :, idx : idx + cur_size
-            ] = metric.windowed_click_total[:, :cur_size]
-            self.windowed_weight_total[
-                :, idx : idx + cur_size
-            ] = metric.windowed_weight_total[:, :cur_size]
+            self.windowed_click_total[:, idx : idx + cur_size] = (
+                metric.windowed_click_total[:, :cur_size]
+            )
+            self.windowed_weight_total[:, idx : idx + cur_size] = (
+                metric.windowed_weight_total[:, :cur_size]
+            )
             idx += cur_size
             self.total_updates += metric.total_updates
 
